[Python-checkins] cpython: Issue #18203: Replace malloc() with PyMem_Malloc() in

victor.stinner python-checkins at python.org
Sun Jul 7 17:26:38 CEST 2013


http://hg.python.org/cpython/rev/10db0c67fc72
changeset:   84499:10db0c67fc72
user:        Victor Stinner <victor.stinner at gmail.com>
date:        Sun Jul 07 17:22:41 2013 +0200
summary:
  Issue #18203:  Replace malloc() with PyMem_Malloc() in _PySequence_BytesToCharpArray()

files:
  Objects/abstract.c |  19 +++++++++++--------
  1 files changed, 11 insertions(+), 8 deletions(-)


diff --git a/Objects/abstract.c b/Objects/abstract.c
--- a/Objects/abstract.c
+++ b/Objects/abstract.c
@@ -1238,7 +1238,7 @@
   to be an int or have an __int__ method. Steals integral's
   reference. error_format will be used to create the TypeError if integral
   isn't actually an Integral instance. error_format should be a format string
-  that can accept a char* naming integral's type. 
+  that can accept a char* naming integral's type.
 */
 static PyObject *
 convert_integral_to_int(PyObject *integral, const char *error_format)
@@ -1257,7 +1257,7 @@
     }
     PyErr_Format(PyExc_TypeError, error_format, Py_TYPE(integral)->tp_name);
     Py_DECREF(integral);
-    return NULL;    
+    return NULL;
 }
 
 
@@ -2721,8 +2721,8 @@
  * NULL terminated string pointers with a NULL char* terminating the array.
  * (ie: an argv or env list)
  *
  * Memory allocated for the returned list is allocated using malloc() and MUST
  * be freed by the caller using a free() loop or _Py_FreeCharPArray().
  */
 char *const *
 _PySequence_BytesToCharpArray(PyObject* self)
@@ -2730,6 +2730,7 @@
     char **array;
     Py_ssize_t i, argc;
     PyObject *item = NULL;
+    Py_ssize_t size;
 
     argc = PySequence_Size(self);
     if (argc == -1)
@@ -2742,7 +2743,7 @@
         return NULL;
     }
 
-    array = malloc((argc + 1) * sizeof(char *));
+    array = PyMem_Malloc((argc + 1) * sizeof(char *));
     if (array == NULL) {
         PyErr_NoMemory();
         return NULL;
@@ -2761,11 +2762,13 @@
             array[i] = NULL;
             goto fail;
         }
-        array[i] = strdup(data);
+        size = PyBytes_GET_SIZE(item) + 1;
+        array[i] = PyMem_Malloc(size);
         if (!array[i]) {
             PyErr_NoMemory();
             goto fail;
         }
+        memcpy(array[i], data, size);
         Py_DECREF(item);
     }
     array[argc] = NULL;
@@ -2785,7 +2788,7 @@
 {
     Py_ssize_t i;
     for (i = 0; array[i] != NULL; ++i) {
-        free(array[i]);
+        PyMem_Free(array[i]);
     }
-    free((void*)array);
+    PyMem_Free((void*)array);
 }
@@ -2721,8 +2721,8 @@
  * (ie: an argv or env list)
  *
- * Memory allocated for the returned list is allocated using malloc() and MUST
- * be freed by the caller using a free() loop or _Py_FreeCharPArray().
+ * Memory allocated for the returned list is allocated using PyMem_Malloc()
+ * and MUST be freed by _Py_FreeCharPArray().
  */
 char *const *

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list